@@ -35,8 +35,10 @@ class Parser
     public static $STATEMENT_PARSERS = array(
 
         // MySQL Utility Statements
-        'EXPLAIN'           => 'SqlParser\\Statements\\ExplainStatement',
         'DESCRIBE'          => 'SqlParser\\Statements\\ExplainStatement',
+        'DESC'              => 'SqlParser\\Statements\\ExplainStatement',
+        'EXPLAIN'           => 'SqlParser\\Statements\\ExplainStatement',
+        'FLUSH'             => '',
         'GRANT'             => '',
         'HELP'              => '',
         'SET PASSWORD'      => '',
@@ -80,15 +82,16 @@ class Parser
 
         // Prepared Statements.
         // https://dev.mysql.com/doc/refman/5.7/en/sql-syntax-prepared-statements.html
-        'PREPARE'           => '',
+        'DEALLOCATE'        => '',
         'EXECUTE'           => '',
+        'PREPARE'           => '',
 
         // Transactional and Locking Statements
         // https://dev.mysql.com/doc/refman/5.7/en/commit.html
-        'START TRANSACTION' => 'SqlParser\\Statements\\TransactionStatement',
         'BEGIN'             => 'SqlParser\\Statements\\TransactionStatement',
         'COMMIT'            => 'SqlParser\\Statements\\TransactionStatement',
         'ROLLBACK'          => 'SqlParser\\Statements\\TransactionStatement',
+        'START TRANSACTION' => 'SqlParser\\Statements\\TransactionStatement',
     );
 
     /**
@@ -113,22 +116,26 @@ class Parser
             'class'             => 'SqlParser\\Components\\UnionKeyword',
             'field'             => 'union',
         ),
+        'UNION ALL'             => array(
+            'class'             => 'SqlParser\\Components\\UnionKeyword',
+            'field'             => 'union',
+        ),
 
         // Actual clause parsers.
         'ALTER'                 => array(
             'class'             => 'SqlParser\\Components\\Expression',
             'field'             => 'table',
-            'options'           => array('skipColumn' => true),
+            'options'           => array('parseField' => 'table'),
         ),
         'ANALYZE'               => array(
             'class'             => 'SqlParser\\Components\\ExpressionArray',
             'field'             => 'tables',
-            'options'           => array('skipColumn' => true),
+            'options'           => array('parseField' => 'table'),
         ),
         'BACKUP'                => array(
             'class'             => 'SqlParser\\Components\\ExpressionArray',
             'field'             => 'tables',
-            'options'           => array('skipColumn' => true),
+            'options'           => array('parseField' => 'table'),
         ),
         'CALL'                  => array(
             'class'             => 'SqlParser\\Components\\FunctionCall',
@@ -137,22 +144,22 @@ class Parser
         'CHECK'                 => array(
             'class'             => 'SqlParser\\Components\\ExpressionArray',
             'field'             => 'tables',
-            'options'           => array('skipColumn' => true),
+            'options'           => array('parseField' => 'table'),
         ),
         'CHECKSUM'              => array(
             'class'             => 'SqlParser\\Components\\ExpressionArray',
             'field'             => 'tables',
-            'options'           => array('skipColumn' => true),
+            'options'           => array('parseField' => 'table'),
         ),
         'DROP'                  => array(
             'class'             => 'SqlParser\\Components\\ExpressionArray',
             'field'             => 'fields',
-            'options'           => array('skipColumn' => true),
+            'options'           => array('parseField' => 'table'),
         ),
         'FROM'                  => array(
             'class'             => 'SqlParser\\Components\\ExpressionArray',
             'field'             => 'from',
-            'options'           => array('skipColumn' => true),
+            'options'           => array('parseField' => 'table'),
         ),
         'GROUP BY'              => array(
             'class'             => 'SqlParser\\Components\\OrderKeyword',
@@ -194,6 +201,10 @@ class Parser
             'class'             => 'SqlParser\\Components\\JoinKeyword',
             'field'             => 'join',
         ),
+        'STRAIGHT_JOIN'         => array(
+            'class'             => 'SqlParser\\Components\\JoinKeyword',
+            'field'             => 'join',
+        ),
         'LIMIT'                 => array(
             'class'             => 'SqlParser\\Components\\Limit',
             'field'             => 'limit',
@@ -201,7 +212,7 @@ class Parser
         'OPTIMIZE'              => array(
             'class'             => 'SqlParser\\Components\\ExpressionArray',
             'field'             => 'tables',
-            'options'           => array('skipColumn' => true),
+            'options'           => array('parseField' => 'table'),
         ),
         'ORDER BY'              => array(
             'class'             => 'SqlParser\\Components\\OrderKeyword',
@@ -222,12 +233,12 @@ class Parser
         'REPAIR'                => array(
             'class'             => 'SqlParser\\Components\\ExpressionArray',
             'field'             => 'tables',
-            'options'           => array('skipColumn' => true),
+            'options'           => array('parseField' => 'table'),
         ),
         'RESTORE'               => array(
             'class'             => 'SqlParser\\Components\\ExpressionArray',
             'field'             => 'tables',
-            'options'           => array('skipColumn' => true),
+            'options'           => array('parseField' => 'table'),
         ),
         'SET'                   => array(
             'class'             => 'SqlParser\\Components\\SetOperation',
@@ -240,12 +251,12 @@ class Parser
         'TRUNCATE'              => array(
             'class'             => 'SqlParser\\Components\\Expression',
             'field'             => 'table',
-            'options'           => array('skipColumn' => true),
+            'options'           => array('parseField' => 'table'),
         ),
         'UPDATE'                => array(
             'class'             => 'SqlParser\\Components\\ExpressionArray',
             'field'             => 'tables',
-            'options'           => array('skipColumn' => true),
+            'options'           => array('parseField' => 'table'),
         ),
         'VALUE'                 => array(
             'class'             => 'SqlParser\\Components\\Array2d',
@@ -350,11 +361,11 @@ class Parser
         $lastStatement = null;
 
         /**
-         * Whether a union is parsed or not.
+         * Union's type or false for no union.
          *
-         * @var bool $inUnion
+         * @var bool|string $unionType
          */
-        $inUnion = false;
+        $unionType = false;
 
         /**
          * The index of the last token from the last statement.
@@ -411,8 +422,8 @@ class Parser
                 continue;
             }
 
-            if ($token->value === 'UNION') {
-                $inUnion = true;
+            if (($token->value === 'UNION') || ($token->value === 'UNION ALL')) {
+                $unionType = $token->value;
                 continue;
             }
 
@@ -459,7 +470,7 @@ class Parser
             $prevLastIdx = $list->idx;
 
             // Handles unions.
-            if (($inUnion)
+            if ((!empty($unionType))
                 && ($lastStatement instanceof SelectStatement)
                 && ($statement instanceof SelectStatement)
             ) {
@@ -474,7 +485,7 @@ class Parser
                  *
                  * @var SelectStatement $lastStatement
                  */
-                $lastStatement->union[] = $statement;
+                $lastStatement->union[] = array($unionType, $statement);
 
                 // if there are no no delimiting brackets, the `ORDER` and
                 // `LIMIT` keywords actually belong to the first statement.
@@ -487,7 +498,7 @@ class Parser
                 // union ends.
                 $lastStatement->last = $statement->last;
 
-                $inUnion = false;
+                $unionType = false;
                 continue;
             }
 
